=======
Credits
=======

Team
-----

* Diego Kiedanski
* Daniel Kofman
* José Horta

Development Lead
----------------

* Diego Kiedanki <gusok@protonmail.com>

Contributors
------------

None yet. Why not be the first?